@@ -1,7 +1,7 @@
 package Data::Sah::Coerce;
 
-our $DATE = '2016-05-27'; # DATE
-our $VERSION = '0.014'; # VERSION
+our $DATE = '2016-06-04'; # DATE
+our $VERSION = '0.015'; # VERSION
 
 use 5.010001;
 use strict;
@@ -117,7 +117,7 @@ Data::Sah::Coerce - Coercion rules for Data::Sah
 
 =head1 VERSION
 
-This document describes version 0.014 of Data::Sah::Coerce (from Perl distribution Data-Sah-Coerce), released on 2016-05-27.
+This document describes version 0.015 of Data::Sah::Coerce (from Perl distribution Data-Sah-Coerce), released on 2016-06-04.
 
 =head1 SYNOPSIS
 
@@ -331,6 +331,9 @@ L<Data::Sah>
 
 L<Data::Sah::CoerceJS>
 
+L<App::SahUtils>, including L<coerce-with-sah> to conveniently test coercion
+from the command-line.
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
