@@ -1,7 +1,7 @@
 package Data::Sah::CoerceJS;
 
-our $DATE = '2016-05-27'; # DATE
-our $VERSION = '0.014'; # VERSION
+our $DATE = '2016-06-04'; # DATE
+our $VERSION = '0.015'; # VERSION
 
 use 5.010001;
 use strict;
@@ -9,6 +9,7 @@ use warnings;
 use Log::Any::IfLOG '$log';
 
 use Data::Sah::CoerceCommon;
+use IPC::System::Options;
 use Nodejs::Util qw(get_nodejs_path);
 
 use Exporter qw(import);
@@ -109,8 +110,7 @@ sub gen_coercer {
         print $jsh $src;
         close($jsh) or die "Can't write JS code to file $jsfn: $!";
 
-        my $cmd = "$nodejs_path $jsfn";
-        my $out = `$cmd`;
+        my $out = IPC::System::Options::backtick($nodejs_path, $jsfn);
         $json->decode($out);
     };
 }
@@ -130,7 +130,7 @@ Data::Sah::CoerceJS - Generate coercer code
 
 =head1 VERSION
 
-This document describes version 0.014 of Data::Sah::CoerceJS (from Perl distribution Data-Sah-Coerce), released on 2016-05-27.
+This document describes version 0.015 of Data::Sah::CoerceJS (from Perl distribution Data-Sah-Coerce), released on 2016-06-04.
 
 =head1 SYNOPSIS
 
@@ -196,6 +196,9 @@ feature.
 
 L<Data::Sah::Coerce>
 
+L<App::SahUtils>, including L<coerce-with-sah> to conveniently test coercion
+from the command-line.
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
